@@ -26,22 +26,21 @@
 #include <QtCore/QDir>
 #include <QtDBus/QtDBus>
 
+#include <kdebug.h>
 #include <klocalizedstring.h>
 #include <kpluginfactory.h>
 #include <kprotocolinfo.h>
+#include <kstandarddirs.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
-#include <kurlauthorized.h>
+#include <kauthorized.h>
+#include <kmimetype.h>
 #include <kuser.h>
-#include <KDE4Support/kde_file.h>
+#include <kde_file.h>
 
 #define QL1S(x) QLatin1String(x)
 #define QL1C(x) QLatin1Char(x)
 
-namespace {
-QLoggingCategory category("org.kde.kurifilter-plugins");
-}
-
  /**
   * IMPORTANT:
   *  If you change anything here, please run the regression test
@@ -87,7 +86,7 @@ static QString removeArgs( const QString& _cmd )
     if( spacePos > 0 )
     {
       cmd = cmd.left( spacePos );
-      //qCDebug(category) << "spacePos=" << spacePos << " returning " << cmd;
+      //kDebug(7023) << "spacePos=" << spacePos << " returning " << cmd;
     }
   }
 
@@ -117,7 +116,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   * hackable and is missing a config dialog.
   */
 
-  QUrl url = data.uri();
+  KUrl url = data.uri();
   QString cmd = data.typedString();
 
   // WORKAROUND: Allow the use of '@' in the username component of a URL since
@@ -128,7 +127,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     // Percent encode all but the last '@'.
     QString encodedCmd = QUrl::toPercentEncoding(cmd.left(lastIndex), ":/");
     encodedCmd += cmd.mid(lastIndex);
-    QUrl u (encodedCmd);
+    KUrl u (encodedCmd);
     if (u.isValid()) {
       cmd = encodedCmd;
       url = u;
@@ -136,9 +135,9 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   }
 
   const bool isMalformed = !url.isValid();
-  QString protocol = url.scheme();
+  QString protocol = url.protocol();
 
-  qCDebug(category) << cmd;
+  kDebug(7023) << cmd;
 
   // Fix misparsing of "foo:80", QUrl thinks "foo" is the protocol and "80" is the path.
   // However, be careful not to do that for valid hostless URLs, e.g. file:///foo!
@@ -147,7 +146,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     protocol.clear();
   }
 
-  //qCDebug(category) << "url=" << url << "cmd=" << cmd << "isMalformed=" << isMalformed;
+  //kDebug(7023) << "url=" << url << "cmd=" << cmd << "isMalformed=" << isMalformed;
 
   if (!isMalformed &&
       (protocol.length() == 4) &&
@@ -157,7 +156,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
       (protocol[3]=='p'))
   {
      // Handle "encrypted" URLs like: h++p://www.kde.org
-     url.setScheme( QLatin1String("http"));
+     url.setProtocol( QLatin1String("http"));
      setFilteredUri( data, url);
      setUriType( data, KUriFilterData::NetProtocol );
      return true;
@@ -171,7 +170,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   const QString starthere_proto = QL1S("start-here:");
   if (cmd.indexOf(starthere_proto) == 0 )
   {
-    setFilteredUri( data, QUrl("system:/") );
+    setFilteredUri( data, KUrl("system:/") );
     setUriType( data, KUriFilterData::LocalDir );
     return true;
   }
@@ -191,7 +190,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     else if ((cmd==info_proto) || (cmd==man_proto))
       cmd+='/';
 
-    setFilteredUri( data, QUrl( cmd ));
+    setFilteredUri( data, KUrl( cmd ));
     setUriType( data, KUriFilterData::Help );
     return true;
   }
@@ -202,7 +201,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     // make sure path is unix style
     cmd.replace('\\', '/');
     cmd.prepend( QLatin1String( "smb:" ) );
-    setFilteredUri( data, QUrl( cmd ));
+    setFilteredUri( data, KUrl( cmd ));
     setUriType( data, KUriFilterData::NetProtocol );
     return true;
   }
@@ -215,31 +214,31 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   QString query;
   QString nameFilter;
 
-  if (QUrl(cmd).isRelative() && QDir::isRelativePath(cmd)) {
+  if (KUrl::isRelativeUrl(cmd) && QDir::isRelativePath(cmd)) {
      path = cmd;
-     //qCDebug(category) << "path=cmd=" << path;
+     //kDebug(7023) << "path=cmd=" << path;
   } else {
     if (url.isLocalFile())
     {
-      //qCDebug(category) << "hasRef=" << url.hasRef();
+      //kDebug(7023) << "hasRef=" << url.hasRef();
       // Split path from ref/query
       // but not for "/tmp/a#b", if "a#b" is an existing file,
       // or for "/tmp/a?b" (#58990)
-      if( ( url.hasFragment() || !url.query().isEmpty() )
+      if( ( url.hasRef() || !url.query().isEmpty() )
            && !url.path().endsWith(QL1S("/")) ) // /tmp/?foo is a namefilter, not a query
       {
         path = url.path();
-        ref = url.fragment();
-        //qCDebug(category) << "isLocalFile set path to " << stringDetails( path );
-        //qCDebug(category) << "isLocalFile set ref to " << stringDetails( ref );
+        ref = url.ref();
+        //kDebug(7023) << "isLocalFile set path to " << stringDetails( path );
+        //kDebug(7023) << "isLocalFile set ref to " << stringDetails( ref );
         query = url.query();
-        if (path.isEmpty() && !url.host().isEmpty())
+        if (path.isEmpty() && url.hasHost())
           path = '/';
       }
       else
       {
         path = cmd;
-        //qCDebug(category) << "(2) path=cmd=" << path;
+        //kDebug(7023) << "(2) path=cmd=" << path;
       }
     }
   }
@@ -280,10 +279,10 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     // Environment variable expansion.
     if ( sEnvVarExp.indexIn( path ) == 0 )
     {
-      const char* exp = qgetenv( path.mid( 1, sEnvVarExp.matchedLength() - 1 ).toLocal8Bit().data() );
-      if(exp)
+      QByteArray exp = qgetenv( path.mid( 1, sEnvVarExp.matchedLength() - 1 ).toLocal8Bit().data() );
+      if(! exp.isNull())
       {
-        path.replace( 0, sEnvVarExp.matchedLength(), QString::fromLocal8Bit(exp) );
+        path.replace( 0, sEnvVarExp.matchedLength(), QString::fromLocal8Bit(exp.constData()) );
         expanded = true;
       }
     }
@@ -292,7 +291,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   if ( expanded || cmd.startsWith( '/' ) )
   {
     // Look for #ref again, after $ and ~ expansion (testcase: $QTDIR/doc/html/functions.html#s)
-    // Can't use QUrl here, setPath would escape it...
+    // Can't use KUrl here, setPath would escape it...
     const int pos = path.indexOf('#');
     if ( pos > -1 )
     {
@@ -301,7 +300,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
       {
         ref = path.mid( pos + 1 );
         path = newPath;
-        //qCDebug(category) << "Extracted ref: path=" << path << " ref=" << ref;
+        //kDebug(7023) << "Extracted ref: path=" << path << " ref=" << ref;
       }
     }
   }
@@ -318,7 +317,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   const bool canBeLocalAbsolute = (canBeAbsolute && abs_path[0] =='/' && !isMalformed);
   bool exists = false;
 
-  /*qCDebug(category) << "abs_path=" << abs_path
+  /*kDebug(7023) << "abs_path=" << abs_path
                << "protocol=" << protocol
                << "canBeAbsolute=" << canBeAbsolute
                << "canBeLocalAbsolute=" << canBeLocalAbsolute
@@ -332,9 +331,9 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     int len = path.length();
     if( (len==1 && path[0]=='.') || (len==2 && path[0]=='.' && path[1]=='.') )
         path += '/';
-    //qCDebug(category) << "adding " << abs << " and " << path;
+    //kDebug(7023) << "adding " << abs << " and " << path;
     abs = QDir::cleanPath(abs + '/' + path);
-    //qCDebug(category) << "checking whether " << abs << " exists.";
+    //kDebug(7023) << "checking whether " << abs << " exists.";
     // Check if it exists
     if( KDE::stat( abs, &buff ) == 0 )
     {
@@ -359,7 +358,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
            && KDE::stat( testPath, &buff ) == 0 )
         {
           nameFilter = fileName;
-          //qCDebug(category) << "Setting nameFilter to " << nameFilter;
+          //kDebug(7023) << "Setting nameFilter to " << nameFilter;
           path = testPath;
           exists = true;
         }
@@ -367,16 +366,16 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     }
   }
 
-  //qCDebug(category) << "path =" << path << " isLocalFullPath=" << isLocalFullPath << " exists=" << exists;
+  //kDebug(7023) << "path =" << path << " isLocalFullPath=" << isLocalFullPath << " exists=" << exists;
   if( exists )
   {
-    QUrl u;
+    KUrl u;
     u.setPath(path);
-    //qCDebug(category) << "ref=" << stringDetails(ref) << " query=" << stringDetails(query);
-    u.setFragment(ref);
+    //kDebug(7023) << "ref=" << stringDetails(ref) << " query=" << stringDetails(query);
+    u.setRef(ref);
     u.setQuery(query);
 
-    if (!KUrlAuthorized::authorizeUrlAction( QLatin1String("open"), QUrl(), u))
+    if (!KAuthorized::authorizeUrlAction( QLatin1String("open"), KUrl(), u))
     {
       // No authorization, we pretend it's a file will get
       // an access denied error later on.
@@ -389,7 +388,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     bool isDir = S_ISDIR( buff.st_mode );
     if( !isDir && access ( QFile::encodeName(path).data(), X_OK) == 0 )
     {
-      //qCDebug(category) << "Abs path to EXECUTABLE";
+      //kDebug(7023) << "Abs path to EXECUTABLE";
       setFilteredUri( data, u );
       setUriType( data, KUriFilterData::Executable );
       return true;
@@ -398,16 +397,16 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     // Open "uri" as file:/xxx if it is a non-executable local resource.
     if( isDir || S_ISREG( buff.st_mode ) )
     {
-      //qCDebug(category) << "Abs path as local file or directory";
+      //kDebug(7023) << "Abs path as local file or directory";
       if ( !nameFilter.isEmpty() )
-        u.setPath( u.path() + '/' + nameFilter );
+        u.setFileName( nameFilter );
       setFilteredUri( data, u );
       setUriType( data, ( isDir ) ? KUriFilterData::LocalDir : KUriFilterData::LocalFile );
       return true;
     }
 
     // Should we return LOCAL_FILE for non-regular files too?
-    qCDebug(category) << "File found, but not a regular file nor dir... socket?";
+    kDebug(7023) << "File found, but not a regular file nor dir... socket?";
   }
 
   if( data.checkForExecutables())
@@ -417,12 +416,12 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     // We try hard to avoid parsing any possible command
     // line arguments or options that might have been supplied.
     QString exe = removeArgs( cmd );
-    //qCDebug(category) << "findExe with" << exe;
+    //kDebug(7023) << "findExe with" << exe;
 
-    if (!QStandardPaths::findExecutable( exe ).isNull() )
+    if (!KStandardDirs::findExe( exe ).isNull() )
     {
-      //qCDebug(category) << "EXECUTABLE  exe=" << exe;
-      setFilteredUri( data, QUrl::fromLocalFile( exe ));
+      //kDebug(7023) << "EXECUTABLE  exe=" << exe;
+      setFilteredUri( data, KUrl::fromPath( exe ));
       // check if we have command line arguments
       if( exe != cmd )
           setArguments(data, cmd.right(cmd.length() - exe.length()));
@@ -436,7 +435,7 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   // slow things down...
   if ( !isMalformed && !isLocalFullPath && !protocol.isEmpty() )
   {
-    //qCDebug(category) << "looking for protocol " << protocol;
+    //kDebug(7023) << "looking for protocol " << protocol;
     if ( KProtocolInfo::isKnownProtocol( protocol ) )
     {
       setFilteredUri( data, url );
@@ -458,9 +457,9 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
     {
       if (hint.regexp.indexIn(cmd) == 0)
       {
-        //qCDebug(category) << "match - prepending" << (*it).prepend;
+        //kDebug(7023) << "match - prepending" << (*it).prepend;
         const QString cmdStr = hint.prepend + cmd;
-        QUrl url(cmdStr);
+        KUrl url(cmdStr);
         if (KProtocolInfo::isKnownProtocol(url))
         {
           setFilteredUri( data, url );
@@ -486,13 +485,13 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
         urlStr += QL1S("://");
       urlStr += cmd;
 
-      QUrl url (urlStr);
+      KUrl url (urlStr);
       if (url.isValid())
       {
         setFilteredUri(data, url);
         setUriType(data, KUriFilterData::NetProtocol);
       }
-      else if (KProtocolInfo::isKnownProtocol(url.scheme()))
+      else if (KProtocolInfo::isKnownProtocol(url.protocol()))
       {
         setFilteredUri(data, data.uri());
         setUriType(data, KUriFilterData::Error);
@@ -505,11 +504,11 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
   // and if it doesn't exist, then error
   if( isLocalFullPath && !exists )
   {
-    QUrl u;
+    KUrl u;
     u.setPath(path);
-    u.setFragment(ref);
+    u.setRef(ref);
 
-    if (!KUrlAuthorized::authorizeUrlAction( QL1S("open"), QUrl(), u))
+    if (!KAuthorized::authorizeUrlAction( QL1S("open"), KUrl(), u))
     {
       // No authorization, we pretend it exists and will get
       // an access denied error later on.
@@ -517,8 +516,8 @@ bool KShortUriFilter::filterUri( KUriFilterData& data ) const
       setUriType( data, KUriFilterData::LocalFile );
       return true;
     }
-    //qCDebug(category) << "fileNotFound -> ERROR";
-    setErrorMsg( data, i18n( "<qt>The file or folder <b>%1</b> does not exist.</qt>", data.uri().toDisplayString() ) );
+    //kDebug(7023) << "fileNotFound -> ERROR";
+    setErrorMsg( data, i18n( "<qt>The file or folder <b>%1</b> does not exist.</qt>", data.uri().prettyUrl() ) );
     setUriType( data, KUriFilterData::Error );
     return true;
   }
